#########################################################################
#	       Makefile for making NASM v0.97 using Ncc			#
#########################################################################
# Revised: 18/Jun/99  hans.walheim@acm.org				#
#    http://www.bahnhof.se/~inters/downld.html				#
#    http://www.geocities.com/SiliconValley/Hub/6461/			#
#									#
#									#
# Note: you may have to modify ms.rsp to get the correct #include path	#
#       to your installation of MSVC					#
#									#
#									#
# Invocation:								#
#   nmake -f nasm097.mak {USE_GNU=1}					#
#									#
#########################################################################

#########################################################################
# Tool configurations
#########################################################################

CC	= ncc

!ifdef USE_GNU
CFLAGS	= @gnu.rsp -S
!else
CFLAGS	= @ms.rsp -S
!endif

AS	= nasmw
AFL	= -s -f win32

!ifdef USE_GNU
LINK	= gcc
LINKFLAGS =
LOUT	= -o
LIBRARIES =

!else
LINK	= link
LINKFLAGS = /incremental:no
LOUT	= /out:
LIBRARIES = libc.lib

!endif

#########################################################################
# Nasm default's.  May be usable for Linux/NT configurations later on
#########################################################################

EXE	= .exe#
OBJ	= obj#
SUFFIX	= w#

#########################################################################
#
#########################################################################

NASMOBJS = nasm.$(OBJ) nasmlib.$(OBJ) float.$(OBJ) insnsa.$(OBJ)	\
           assemble.$(OBJ) labels.$(OBJ) parser.$(OBJ) outform.$(OBJ)	\
	   outbin.$(OBJ) outaout.$(OBJ) outcoff.$(OBJ) outelf.$(OBJ)	\
	   outobj.$(OBJ) outas86.$(OBJ) outrdf.$(OBJ) outdbg.$(OBJ)	\
	   preproc.$(OBJ) listing.$(OBJ) eval.$(OBJ)

NDISASMOBJS = ndisasm.$(OBJ) disasm.$(OBJ) sync.$(OBJ) nasmlib.$(OBJ)	\
              insnsd.$(OBJ)

#########################################################################
#
#########################################################################
all : nasm$(SUFFIX)$(EXE) ndisasm$(SUFFIX)$(EXE)

#########################################################################
#
#########################################################################
nasm$(SUFFIX)$(EXE): $(NASMOBJS)
	$(LINK) $(LINKFLAGS) $(LOUT)nasm$(SUFFIX).exe $(NASMOBJS)	\
		$(NCC_LIB)intrins.lib $(LIBRARIES)

ndisasm$(SUFFIX)$(EXE): $(NDISASMOBJS)
	$(LINK) $(LINKFLAGS) $(LOUT)ndisasm$(SUFFIX).exe $(NDISASMOBJS) \
		$(NCC_LIB)intrins.lib  $(LIBRARIES)

#########################################################################
#
#########################################################################
assemble.$(OBJ): assemble.c nasm.h assemble.h insns.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

disasm.$(OBJ): disasm.c nasm.h disasm.h sync.h insns.h names.c
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

eval.$(OBJ): eval.c nasm.h nasmlib.h eval.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

float.$(OBJ): float.c nasm.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

insnsa.$(OBJ): insnsa.c nasm.h insns.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

insnsd.$(OBJ): insnsd.c nasm.h insns.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

labels.$(OBJ): labels.c nasm.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

listing.$(OBJ): listing.c nasm.h nasmlib.h listing.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

nasm.$(OBJ): nasm.c nasm.h nasmlib.h parser.h assemble.h labels.h \
	listing.h outform.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

nasmlib.$(OBJ): nasmlib.c nasm.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

ndisasm.$(OBJ): ndisasm.c nasm.h sync.h disasm.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

outas86.$(OBJ): outas86.c nasm.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

outaout.$(OBJ): outaout.c nasm.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

outbin.$(OBJ): outbin.c nasm.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

outcoff.$(OBJ): outcoff.c nasm.h nasmlib.h
	-$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

outdbg.$(OBJ): outdbg.c nasm.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

outelf.$(OBJ): outelf.c nasm.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

outobj.$(OBJ): outobj.c nasm.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

outrdf.$(OBJ): outrdf.c nasm.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

outform.$(OBJ): outform.c outform.h nasm.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

parser.$(OBJ): parser.c nasm.h nasmlib.h parser.h float.h names.c
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

sync.$(OBJ): sync.c sync.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm

preproc.$(OBJ): preproc.c macros.c preproc.h nasm.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFL) $*.asm


clean :
	del *.$(OBJ)
	del nasm$(SUFFIX)$(EXE)
	del ndisasm$(SUFFIX)$(EXE)
