#########################################################################
#	       Makefile for making NASM v0.98 using Ncc			#
#########################################################################
# Revised: 18/Jun/99  hans.walheim@acm.org				#
#    http://www.bahnhof.se/~inters/downld.html				#
#    http://www.geocities.com/SiliconValley/Hub/6461/			#
#									#
#									#
# Note: you may have to modify ms.rsp to get the correct #include path	#
#       to your installation of MSVC					#
#	You must change the first declaration of 'of_obj' in outobj.c	#
#	to be 'extern'. Ncc cannot handle tentative definitions		#
#									#
#									#
# Invocation:								#
#   nmake -f nasm098.mak {USE_GNU=1}					#
#									#
#########################################################################

#########################################################################
# Tool configurations
#########################################################################

CC	= ncc

!ifdef USE_GNU
CFLAGS	= @gnu.rsp -S
!else
CFLAGS	= @ms.rsp -S
!endif

AS	= nasmw
AFLAGS	= -s -f win32

!ifdef USE_GNU
LINK	= gcc
LINKFLAGS =
LOUT	= -o
LIBRARIES =

!else
LINK	= link
LINKFLAGS = /incremental:no
LOUT	= /out:
LIBRARIES = libc.lib

!endif

#########################################################################
# Nasm default's.  May be usable for Linux/NT configurations later on
#########################################################################

EXE	= .exe#
OBJ	= obj#
SUFFIX	= w#

#########################################################################
#
#########################################################################

NASMOBJS = nasm.$(OBJ)     nasmlib.$(OBJ)  float.$(OBJ)   insnsa.$(OBJ)	\
           assemble.$(OBJ) labels.$(OBJ)   parser.$(OBJ)  outform.$(OBJ)\
	   outbin.$(OBJ)   outaout.$(OBJ)  outcoff.$(OBJ) outelf.$(OBJ)	\
	   outobj.$(OBJ)   outas86.$(OBJ)  outrdf.$(OBJ)  outrdf2.$(OBJ)\
	   outdbg.$(OBJ)   zoutieee.$(OBJ) preproc.$(OBJ) listing.$(OBJ)\
	   eval.$(OBJ)

NDISASMOBJS = \
	   ndisasm.$(OBJ)  disasm.$(OBJ)   sync.$(OBJ)   nasmlib.$(OBJ)	\
	   insnsd.$(OBJ)

#########################################################################
#
#########################################################################
all : nasm$(SUFFIX)$(EXE) ndisasm$(SUFFIX)$(EXE)

#########################################################################
#
#########################################################################
nasm$(SUFFIX)$(EXE): $(NASMOBJS)
	$(LINK) $(LINKFLAGS) $(LOUT)nasm$(SUFFIX).exe $(NASMOBJS)	\
		$(NCC_LIB)intrins.lib $(LIBRARIES)

ndisasm$(SUFFIX)$(EXE): $(NDISASMOBJS)
	$(LINK) $(LINKFLAGS) $(LOUT)ndisasm$(SUFFIX).exe $(NDISASMOBJS) \
		$(NCC_LIB)intrins.lib  $(LIBRARIES)

#########################################################################
#
#########################################################################

assemble.$(OBJ): assemble.c nasm.h insnsi.h assemble.h insns.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

disasm.$(OBJ): disasm.c nasm.h insnsi.h disasm.h sync.h insns.h names.c insnsn.c
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

eval.$(OBJ): eval.c nasm.h insnsi.h nasmlib.h eval.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

float.$(OBJ): float.c nasm.h insnsi.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

insnsa.$(OBJ): insnsa.c nasm.h insnsi.h insns.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

insnsd.$(OBJ): insnsd.c nasm.h insnsi.h insns.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

labels.$(OBJ): labels.c nasm.h insnsi.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

listing.$(OBJ): listing.c nasm.h insnsi.h nasmlib.h listing.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

nasm.$(OBJ): nasm.c nasm.h insnsi.h nasmlib.h parser.h assemble.h labels.h \
	listing.h outform.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

nasmlib.$(OBJ): nasmlib.c nasm.h insnsi.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

ndisasm.$(OBJ): ndisasm.c nasm.h insnsi.h sync.h disasm.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

outas86.$(OBJ): outas86.c nasm.h insnsi.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

outaout.$(OBJ): outaout.c nasm.h insnsi.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

outbin.$(OBJ): outbin.c nasm.h insnsi.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

outcoff.$(OBJ): outcoff.c nasm.h insnsi.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

outdbg.$(OBJ): outdbg.c nasm.h insnsi.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

outelf.$(OBJ): outelf.c nasm.h insnsi.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

outobj.$(OBJ): outobj.c nasm.h insnsi.h nasmlib.h
	@echo outobj.c,592: Error[0]:You must change the first declaration of 'of_obj' to be 'extern'
	@echo outobj.c,592: Error[0]:The C++-ishness of Ncc cannot handle tentative definitions !
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

outrdf.$(OBJ): outrdf.c nasm.h insnsi.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

outrdf2.$(OBJ): outrdf2.c nasm.h insnsi.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

outform.$(OBJ): outform.c outform.h nasm.h insnsi.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

parser.$(OBJ): parser.c nasm.h insnsi.h nasmlib.h parser.h float.h names.c insnsn.c
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

preproc.$(OBJ): preproc.c macros.c preproc.h nasm.h insnsi.h nasmlib.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

sync.$(OBJ): sync.c sync.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm

zoutieee.$(OBJ): zoutieee.c nasm.h insnsi.h nasmlib.h outform.h
	$(CC) $(CFLAGS) $*.c
	$(AS) $(AFLAGS) $*.asm


clean :
	del *.$(OBJ)
	del nasm$(SUFFIX)$(EXE)
	del ndisasm$(SUFFIX)$(EXE)
